var indexSectionsWithContent =
{
  0: "acegimstuvx",
  1: "x",
  2: "x",
  3: "acgs",
  4: "ivx",
  5: "mx"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Pages"
};

